@@ -1,5 +1,5 @@
 /*  Arg_parser - A POSIX/GNU command line argument parser.
-    Copyright (C) 2006, 2007, 2008 Antonio Diaz Diaz.
+    Copyright (C) 2006, 2007, 2008, 2009 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 */
 
 #include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <string>
 #include <vector>
 
@@ -33,10 +35,10 @@ namespace {
 const char * invocation_name = 0;
 const char * const Program_name    = "Arg_parser";
 const char * const program_name    = "arg_parser";
-const char * const program_year    = "2008";
+const char * const program_year    = "2009";
 
 
-void show_help( const bool verbose ) throw()
+void show_help( const bool verbose )
   {
   std::printf( "%s - A POSIX/GNU command line argument parser.\n", Program_name );
   std::printf( "See the source file `main.cc' to learn how to use %s in\n", Program_name );
@@ -61,7 +63,7 @@ void show_help( const bool verbose ) throw()
   }
 
 
-void show_version() throw()
+void show_version()
   {
   std::printf( "%s %s\n", Program_name, PROGVERSION );
   std::printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
@@ -71,12 +73,12 @@ void show_version() throw()
   }
 
 
-void show_error( const char * msg, const int errcode = 0, const bool help = false ) throw()
+void show_error( const char * msg, const int errcode = 0, const bool help = false )
   {
   if( msg && msg[0] != 0 )
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) std::fprintf( stderr, ": %s", strerror( errcode ) );
+    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
     std::fprintf( stderr, "\n" );
     }
   if( help && invocation_name && invocation_name[0] != 0 )
@@ -84,16 +86,16 @@ void show_error( const char * msg, const int errcode = 0, const bool help = fals
   }
 
 
-void internal_error( const char * msg ) throw()
+void internal_error( const char * msg )
   {
   char buf[80];
   std::snprintf( buf, sizeof( buf ), "internal error: %s.\n", msg );
   show_error( buf );
-  exit( 3 );
+  std::exit( 3 );
   }
 
 
-const char * optname( const int code, const Arg_parser::Option options[] ) throw()
+const char * optname( const int code, const Arg_parser::Option options[] )
   {
   static char buf[2] = "?";
 
@@ -108,7 +110,7 @@ const char * optname( const int code, const Arg_parser::Option options[] ) throw
 } // end namespace
 
 
-int main( const int argc, const char * argv[] ) throw()
+int main( const int argc, const char * argv[] )
   {
   bool verbose = false;
   invocation_name = argv[0];
